lcvtoolbox.integrations.huggingface.image\_classification.HfApi
===============================================================

.. currentmodule:: lcvtoolbox.integrations.huggingface.image_classification

.. autoclass:: HfApi
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~HfApi.__init__
      ~HfApi.accept_access_request
      ~HfApi.add_collection_item
      ~HfApi.add_space_secret
      ~HfApi.add_space_variable
      ~HfApi.auth_check
      ~HfApi.cancel_access_request
      ~HfApi.change_discussion_status
      ~HfApi.comment_discussion
      ~HfApi.create_branch
      ~HfApi.create_collection
      ~HfApi.create_commit
      ~HfApi.create_discussion
      ~HfApi.create_inference_endpoint
      ~HfApi.create_inference_endpoint_from_catalog
      ~HfApi.create_pull_request
      ~HfApi.create_repo
      ~HfApi.create_tag
      ~HfApi.create_webhook
      ~HfApi.dataset_info
      ~HfApi.delete_branch
      ~HfApi.delete_collection
      ~HfApi.delete_collection_item
      ~HfApi.delete_file
      ~HfApi.delete_files
      ~HfApi.delete_folder
      ~HfApi.delete_inference_endpoint
      ~HfApi.delete_repo
      ~HfApi.delete_space_secret
      ~HfApi.delete_space_storage
      ~HfApi.delete_space_variable
      ~HfApi.delete_tag
      ~HfApi.delete_webhook
      ~HfApi.disable_webhook
      ~HfApi.duplicate_space
      ~HfApi.edit_discussion_comment
      ~HfApi.enable_webhook
      ~HfApi.file_exists
      ~HfApi.get_collection
      ~HfApi.get_dataset_tags
      ~HfApi.get_discussion_details
      ~HfApi.get_full_repo_name
      ~HfApi.get_hf_file_metadata
      ~HfApi.get_inference_endpoint
      ~HfApi.get_model_tags
      ~HfApi.get_paths_info
      ~HfApi.get_repo_discussions
      ~HfApi.get_safetensors_metadata
      ~HfApi.get_space_runtime
      ~HfApi.get_space_variables
      ~HfApi.get_token_permission
      ~HfApi.get_user_overview
      ~HfApi.get_webhook
      ~HfApi.grant_access
      ~HfApi.hf_hub_download
      ~HfApi.hide_discussion_comment
      ~HfApi.list_accepted_access_requests
      ~HfApi.list_collections
      ~HfApi.list_datasets
      ~HfApi.list_inference_catalog
      ~HfApi.list_inference_endpoints
      ~HfApi.list_lfs_files
      ~HfApi.list_liked_repos
      ~HfApi.list_models
      ~HfApi.list_organization_members
      ~HfApi.list_papers
      ~HfApi.list_pending_access_requests
      ~HfApi.list_rejected_access_requests
      ~HfApi.list_repo_commits
      ~HfApi.list_repo_files
      ~HfApi.list_repo_likers
      ~HfApi.list_repo_refs
      ~HfApi.list_repo_tree
      ~HfApi.list_spaces
      ~HfApi.list_user_followers
      ~HfApi.list_user_following
      ~HfApi.list_webhooks
      ~HfApi.merge_pull_request
      ~HfApi.model_info
      ~HfApi.move_repo
      ~HfApi.paper_info
      ~HfApi.parse_safetensors_file_metadata
      ~HfApi.pause_inference_endpoint
      ~HfApi.pause_space
      ~HfApi.permanently_delete_lfs_files
      ~HfApi.preupload_lfs_files
      ~HfApi.reject_access_request
      ~HfApi.rename_discussion
      ~HfApi.repo_exists
      ~HfApi.repo_info
      ~HfApi.request_space_hardware
      ~HfApi.request_space_storage
      ~HfApi.restart_space
      ~HfApi.resume_inference_endpoint
      ~HfApi.revision_exists
      ~HfApi.run_as_future
      ~HfApi.scale_to_zero_inference_endpoint
      ~HfApi.set_space_sleep_time
      ~HfApi.snapshot_download
      ~HfApi.space_info
      ~HfApi.super_squash_history
      ~HfApi.unlike
      ~HfApi.update_collection_item
      ~HfApi.update_collection_metadata
      ~HfApi.update_inference_endpoint
      ~HfApi.update_repo_settings
      ~HfApi.update_repo_visibility
      ~HfApi.update_webhook
      ~HfApi.upload_file
      ~HfApi.upload_folder
      ~HfApi.upload_large_folder
      ~HfApi.whoami
   
   

   
   
   